@@ -13,6 +13,7 @@
 #include "sa/MultiGeary.h"
 #include "sa/MultiJoinCount.h"
 #include "sa/BatchLocalMoran.h"
+#include "sa/BiLocalMoran.h"
 #include "gda_data.h"
 #include "GenUtils.h"
 #include "gda_sa.h"
@@ -77,6 +78,28 @@ LISA *gda_localmoran(GeoDaWeight *w,
     return lisa;
 }
 
+LISA *gda_bi_localmoran(GeoDaWeight *w,
+                        const std::vector<double> &data1,
+                        const std::vector<double> &data2,
+                        const std::vector<bool> &undefs,
+                        double significance_cutoff,
+                        int nCPUs, int permutations, const std::string& perm_method, int last_seed_used)
+{
+    if (w == 0)
+        return 0;
+
+    int num_obs = w->num_obs;
+
+    std::vector<bool> copy_undefs = undefs;
+    if (copy_undefs.empty())
+    {
+        copy_undefs.resize(num_obs, false);
+    }
+
+    BiLocalMoran *lisa = new BiLocalMoran(num_obs, w, data1, data2, copy_undefs, significance_cutoff, nCPUs, permutations, perm_method, last_seed_used);
+    return lisa;
+}
+
 LISA *gda_localmoran_eb(GeoDaWeight *w,
                         const std::vector<double> &event_data,
                         const std::vector<double> &base_data,
